@@ -4,19 +4,19 @@ require 'mail_room/delivery/logger'
 describe MailRoom::Delivery::Logger do
   describe '#initialize' do
     context "without a log path" do
-      let(:mailbox) {MailRoom::Mailbox.new}
+      let(:mailbox) {build_mailbox}
 
       it 'creates a new ruby logger' do
         ::Logger.stubs(:new)
 
         MailRoom::Delivery::Logger.new(mailbox)
 
-        ::Logger.should have_received(:new).with(STDOUT)
+        expect(::Logger).to have_received(:new).with(STDOUT)
       end
     end
 
     context "with a log path" do
-      let(:mailbox) {MailRoom::Mailbox.new(:log_path => '/var/log/mail-room.log')}
+      let(:mailbox) {build_mailbox(:log_path => '/var/log/mail-room.log')}
 
       it 'creates a new file to append to' do
         ::Logger.stubs(:new)
@@ -25,14 +25,14 @@ describe MailRoom::Delivery::Logger do
 
         MailRoom::Delivery::Logger.new(mailbox)
 
-        File.should have_received(:open).with('/var/log/mail-room.log', 'a')
-        ::Logger.should have_received(:new).with(file)
+        expect(File).to have_received(:open).with('/var/log/mail-room.log', 'a')
+        expect(::Logger).to have_received(:new).with(file)
       end
     end
   end
 
   describe '#deliver' do
-    let(:mailbox) {MailRoom::Mailbox.new}
+    let(:mailbox) {build_mailbox}
 
     it 'writes the message to info' do
       logger = stub(:info)
@@ -40,7 +40,7 @@ describe MailRoom::Delivery::Logger do
 
       MailRoom::Delivery::Logger.new(mailbox).deliver('a message')
 
-      logger.should have_received(:info).with('a message')
+      expect(logger).to have_received(:info).with('a message')
     end
   end
 end
